@@ -1,12 +1,12 @@
 from datetime import datetime, date, time
 from decimal import Decimal
 from operator import itemgetter
+import six
 
 from django import forms
 from django.contrib import admin, messages
 from django.contrib.admin import widgets
 from django.contrib.admin.options import csrf_protect_m
-from django.conf.urls import patterns, url
 from django.core.exceptions import PermissionDenied
 from django.forms import fields
 from django.http import HttpResponseRedirect
@@ -15,27 +15,40 @@ from django.template.context import RequestContext
 from django.utils.formats import localize
 from django.utils.translation import ugettext as _
 
+try:
+    from django.conf.urls import patterns, url
+except ImportError:  # Django < 1.4
+    from django.conf.urls.defaults import patterns, url
+
+
 from constance import config, settings
 
 
 NUMERIC_WIDGET = forms.TextInput(attrs={'size': 10})
 
 INTEGER_LIKE = (fields.IntegerField, {'widget': NUMERIC_WIDGET})
-STRING_LIKE = (fields.CharField, {'widget': forms.Textarea(attrs={'rows': 3}), 'required': False})
+STRING_LIKE = (fields.CharField, {
+    'widget': forms.Textarea(attrs={'rows': 3}),
+    'required': False,
+})
 
 FIELDS = {
     bool: (fields.BooleanField, {'required': False}),
     int: INTEGER_LIKE,
-    long: INTEGER_LIKE,
     Decimal: (fields.DecimalField, {'widget': NUMERIC_WIDGET}),
     str: STRING_LIKE,
-    unicode: STRING_LIKE,
     datetime: (fields.DateTimeField, {'widget': widgets.AdminSplitDateTime}),
     date: (fields.DateField, {'widget': widgets.AdminDateWidget}),
     time: (fields.TimeField, {'widget': widgets.AdminTimeWidget}),
     float: (fields.FloatField, {'widget': NUMERIC_WIDGET}),
 }
 
+if not six.PY3:
+    FIELDS.update({
+        long: INTEGER_LIKE,
+        unicode: STRING_LIKE,
+    })
+
 
 class ConstanceForm(forms.Form):
     def __init__(self, *args, **kwargs):
@@ -56,12 +69,10 @@ class ConstanceAdmin(admin.ModelAdmin):
         return patterns('',
             url(r'^$',
                 self.admin_site.admin_view(self.changelist_view),
-                name='%s_%s_changelist' % info
-            ),
+                name='%s_%s_changelist' % info),
             url(r'^$',
                 self.admin_site.admin_view(self.changelist_view),
-                name='%s_%s_add' % info
-            ),
+                name='%s_%s_add' % info),
         )
 
     @csrf_protect_m
@@ -70,7 +81,7 @@ class ConstanceAdmin(admin.ModelAdmin):
         if not self.has_change_permission(request, None):
             raise PermissionDenied
         default_initial = ((name, default)
-            for name, (default, help_text) in settings.CONFIG.iteritems())
+            for name, (default, help_text) in settings.CONFIG.items())
         # Then update the mapping with actually values from the backend
         initial = dict(default_initial,
             **dict(config._backend.mget(settings.CONFIG.keys())))
@@ -94,7 +105,7 @@ class ConstanceAdmin(admin.ModelAdmin):
             'form': form,
             'media': self.media + form.media,
         }
-        for name, (default, help_text) in settings.CONFIG.iteritems():
+        for name, (default, help_text) in settings.CONFIG.items():
             # First try to load the value from the actual backend
             value = initial.get(name)
             # Then if the returned value is None, get the default
@@ -106,10 +117,11 @@ class ConstanceAdmin(admin.ModelAdmin):
                 'help_text': _(help_text),
                 'value': localize(value),
                 'modified': value != default,
-                'form_field': form[name]
+                'form_field': form[name],
             })
         context['config'].sort(key=itemgetter('name'))
-        context_instance = RequestContext(request, current_app=self.admin_site.name)
+        context_instance = RequestContext(request,
+                                          current_app=self.admin_site.name)
         return render_to_response('admin/constance/change_list.html',
             context, context_instance=context_instance)
 
@@ -122,8 +134,7 @@ class ConstanceAdmin(admin.ModelAdmin):
     def has_change_permission(self, request, obj=None):
         if settings.SUPERUSER_ONLY:
             return request.user.is_superuser
-        else:
-            return super(ConstanceAdmin, self).has_change_permission(request, obj)
+        return super(ConstanceAdmin, self).has_change_permission(request, obj)
 
 
 class Config(object):
