@@ -7,7 +7,9 @@ class Migration(SchemaMigration):
 
     def forwards(self, orm):
         # Changing field 'Constance.key'
-        db.alter_column('constance_config', 'key', self.gf('django.db.models.fields.CharField')(unique=True, max_length=255))
+        db.alter_column('constance_config', 'key',
+                        self.gf('django.db.models.fields.CharField')(
+                            unique=True, max_length=255))
         # Adding unique constraint on 'Constance', fields ['key']
         db.create_unique('constance_config', ['key'])
 
@@ -16,13 +18,17 @@ class Migration(SchemaMigration):
         db.delete_unique('constance_config', ['key'])
 
         # Changing field 'Constance.key'
-        db.alter_column('constance_config', 'key', self.gf('django.db.models.fields.TextField')())
+        db.alter_column('constance_config', 'key',
+                        self.gf('django.db.models.fields.TextField')())
 
     models = {
         'database.constance': {
-            'Meta': {'object_name': 'Constance', 'db_table': "'constance_config'"},
-            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
-            'key': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '255'}),
+            'Meta': {'object_name': 'Constance',
+                     'db_table': "'constance_config'"},
+            'id': ('django.db.models.fields.AutoField', [],
+                   {'primary_key': 'True'}),
+            'key': ('django.db.models.fields.CharField', [],
+                    {'unique': 'True', 'max_length': '255'}),
             'value': ('picklefield.fields.PickledObjectField', [], {})
         }
     }
